/***************************************************************************
                          mandelbrot.cpp  -  description
                             -------------------
    begin                : Son Mai 11 2003
    copyright            : (C) 2003 by Thomas Dreibholz
    email                : dreibh@exp-math.uni-essen.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "mandelbrot.h"


Mandelbrot* Mandelbrot::Registration = new Mandelbrot();


Mandelbrot::Mandelbrot()
{
}

Mandelbrot::~Mandelbrot()
{
}

const char* Mandelbrot::getName()
{
   return("Mandelbrot z[i+1]=z[i]^2-c");
}

const char* Mandelbrot::getSaveIdentifier()
{
   return("Mandelbrot");
}
           
std::complex<double> Mandelbrot::defaultC1()
{
   return(std::complex<double>(-1.5, 1.5));
}

std::complex<double> Mandelbrot::defaultC2()
{
   return(std::complex<double>(1.5, -1.5));
}

unsigned int Mandelbrot::calculatePoint(const unsigned int x,
                                        const unsigned int y)
{
   const std::complex<double> c = std::complex<double>(C1.real() + ((double)x * StepX),
                                                       C1.imag() + ((double)y * StepY));
   std::complex<double> z(0.0, 0.0);
   unsigned int         i;

   for(i = 0;i < MaxIterations;i++) {
      z = z*z - c;
      if(z.real() * z.real() + z.imag() * z.imag() >= 2.0) {
         return(i);
      }
   }

   return(i);
}
